<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-porte_plume?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// P
	'porte_plume_description' => 'Der Federhalter ist eine erweiterbare Werkzeugleiste für SPIP auf Grundlage der Javascript-Bibiliothek [MarkItUp->http://markitup.jaysalvat.com/home/]',
	'porte_plume_nom' => 'Federhalter',
	'porte_plume_slogan' => 'Eine Menüleiste zum Formatieren der Texte',
];
